@@ -1,5 +1,6 @@
 from jobqueues.localqueue import LocalGPUQueue
 from protocolinterface import ProtocolInterface, val
+from jobqueues.config import loadConfig
 import os
 import logging
 
@@ -12,22 +13,13 @@ class CeleryQueue(LocalGPUQueue):
 
     Start a celery server with:
     >>> docker run -d -p 5462:5672 rabbitmq
-    >>> celery --app=jobqueues.celeryfiles.celery worker --loglevel=info -Q gpu,celery -c 1
+    >>> celery --app=jobqueues.celeryfiles.celery worker --loglevel=info -Q gpu -c 4  -n gpu@%h
+    >>> celery --app=jobqueues.celeryfiles.celery worker --loglevel=info -Q cpu -c 10 -n cpu@%h
     """
 
-    def __init__(self, _configapp=None, _configfile=None, _logger=True):
-        try:
-            from jobqueues.celeryfiles.celery import app
-        except Exception as e:
-            raise RuntimeError(f"Could not import Celery app with error: {e}")
-
-        try:
-            from jobqueues.celeryfiles.tasks import run_simulation
-
-            self._submitfunc = run_simulation
-        except Exception as e:
-            raise RuntimeError(f"Could not import CeleryQueue task with error {e}")
-
+    def __init__(
+        self, _configapp=None, _configfile=None, _logger=True, _checkWorkers=True
+    ):
         super().__init__()
         self._arg(
             "datadir",
@@ -45,23 +37,57 @@ class CeleryQueue(LocalGPUQueue):
             nargs="*",
         )
         self._arg("jobname", "str", "Job name (identifier)", None, val.String())
+        self._arg(
+            "broker", "str", "Broker", "pyamqp://guest@localhost:5462//", val.String()
+        )
+        self._arg("backend", "str", "Result backend", "rpc://", val.String())
+        self._arg(
+            "usesgpu", "bool", "Set to True if jobs use GPU", False, val.Boolean()
+        )
+
+        loadConfig(self, "celery", _configfile, _configapp, _logger)
+
+        try:
+            from celery import Celery
+
+            app = Celery(
+                "tasks",
+                broker=self.broker,
+                backend=self.backend,
+                include=("jobqueues.celeryfiles.tasks",),
+            )
+            app.conf.task_routes = {
+                "jobqueues.celeryfiles.tasks.execute_gpu_job": "gpu",
+                "jobqueues.celeryfiles.tasks.execute_cpu_job": "cpu",
+            }
+        except Exception as e:
+            raise RuntimeError(f"Could not import Celery app with error: {e}")
+
         self._app = app
         try:
-            # This will currently hang instead of crashing if rabbit is down https://github.com/celery/celery/issues/5139
-            # Really annoying issue. Will need to wait for a fix in celery
-            self._workers = list(app.control.inspect().ping().keys())
+            from jobqueues.celeryfiles.tasks import execute_gpu_job, execute_cpu_job
+
+            self._submitfunc = {"gpu": execute_gpu_job, "cpu": execute_cpu_job}
         except Exception as e:
-            raise RuntimeError(f"Could not list Celery workers with error: {e}")
+            raise RuntimeError(f"Could not import CeleryQueue task with error {e}")
 
-        if len(self._workers) == 0:
-            raise RuntimeError("Could not find any running Celery workers.")
+        if _checkWorkers:
+            try:
+                # This will currently hang instead of crashing if rabbit is down https://github.com/celery/celery/issues/5139
+                # Really annoying issue. Will need to wait for a fix in celery
+                self._workers = list(app.control.inspect().ping().keys())
+            except Exception as e:
+                raise RuntimeError(f"Could not list Celery workers with error: {e}")
 
-        if _logger:
-            logger.info(
-                f"CeleryQueue found the following active workers: {self._workers}"
-            )
+            if len(self._workers) == 0:
+                raise RuntimeError("Could not find any running Celery workers.")
 
-        self._insp = self._app.control.inspect(self._workers)
+            if _logger:
+                logger.info(
+                    f"CeleryQueue found the following active workers: {self._workers}"
+                )
+
+            self._insp = self._app.control.inspect(self._workers)
 
     def submit(self, dirs):
         dirs = self._submitinit(dirs)
@@ -78,13 +104,12 @@ class CeleryQueue(LocalGPUQueue):
             runscript = self._getRunScript(dirname)
             self._cleanSentinel(dirname)
 
-            async_res = self._submitfunc.delay(
-                dirname,
-                0,
-                self._sentinel,
-                self.datadir,
-                self.copy,
-                jobname=self.jobname,
+            if self.usesgpu:
+                func = self._submitfunc["gpu"]
+            else:
+                func = self._submitfunc["cpu"]
+            async_res = func.delay(
+                dirname, self._sentinel, self.datadir, self.copy, jobname=self.jobname,
             )
 
     def retrieve(self):
